INSTITUTIONS OF CONFINEMENT: THE ORIGINS OF CANADIAN MENTAL HOSPITALS AND PENITENTIARIES 

Daniel Francis and C. James Taylor 

Introduction 

     Societies have dealt in a variety of ways over time with individuals who cannot or will not conform to accepted standards of behaviour. Early in the nineteenth century theorists and social reformers began to argue first in Europe, then in North America that criminals and the mentally disturbed could be successfully "treated" and rehabilitated. Assuming that insanity and criminal behaviour resulted from an undesirable social and/or personal environment, they maintained that deviant behaviour could be corrected in an improved environment which emphasized discipline and proper standards of conduct. This approach underlay the design of new institutions for the confinement of criminals and the insane the penitentiary and the asylum. These institutions have remained central to the rehabilitation of deviants down to the present day.

     Asylums, as early mental hospitals were called, and penitentiaries may appear to have different purposes, but both were created at about the same time to put into practice similar theories on dealing with deviance. Both were intended to be therapeutic, as opposed to simply custodial, institutions. Both served as "laboratories" for new techniques of behavioral management. Both attempted to use architecture as a force for moral development. Both were created in a burst of reformist optimism, and both deteriorated, partly through mismanagement, into examples of man's inhumanity to man. For all these reasons the penitentiary and the asylum are like non-identical twins; despite their apparent differences they were simultaneously conceived under the same circumstances.

The Emergence of the Age of Confinement 

     At the beginning of the nineteenth century, jails in British North America functioned mainly as holding tanks for offenders between stages in the judicial process; suspects were held in jail until they were tried, then confined until punishment was meted out. For serious crimes, such as treason, murder and even robbery, hanging was the usual punishment. Criminals convicted of lesser offenses might be branded or placed in stocks. Between these two extremes lay an uncertain area of flexible sentences. Although the law defined many crimes against property as capital offenses punishable by death, many magistrates became increasingly reluctant to send criminals to the gallows for crimes other than murder. Since stocks and branding did not seem severe enough for serious crimes, other punishments, such as exile, were implemented. In the Canadian colonies at the beginning of the nineteenth century, short term jail sentences and exile were the most common modes of punishment. Because jails were seldom used for prolonged incarceration, they did not have the importance they would gain later in the century.

     Virtually no institutional framework existed for handling the mentally ill during the early 1800s. If they could support themselves, and broke no laws, the deranged were often at large in the community. Those with sufficient means or wealthy relatives resided in private madhouses, while others were cared for by their families or religious groups. It was only when mentally disturbed people became criminals or paupers that they were sent to either a workhouse or jail.

     In the 1820s and 1830s a few reform minded laymen and doctors in British North America began to complain about the inadequacy of the care given to the mentally ill. Inspired by examples in Europe and the United States, they petitioned the various colonial governments to provide publicly funded and properly managed treatment centres for the insane. Their concern was fuelled in part by new ideas regarding the nature of insanity. Previously, mental illness had been considered a spiritual condition rather than a disease. Robbed of their reason, lunatics were thought to have lost the essence of their humanity. On the assumption that they could not feel pain, loneliness or sorrow in the same way as healthy human beings, they were treated as dumb beasts or worse. Proponents of the newer theories believed lunacy was a disease rooted in environmental factors such as poor health, poverty and damaging family relationships. They believed that by taking the "diseased organ" away "from the cares of his ordinary life, from his bad habits, from that circle...in which he finds permanent danger of relapse" that a person suffering from mental illness could be cured in healthy, sympathetic surroundings. This approach to madness required a new method of handling the insane, one which provided therapy and not simply confinement.

     At the same time, there emerged a growing body of opinion, in both Europe and North America, in favour of improving the penal system. Depending on what motivated them the most, these would-be reformers fell into three categories: those who complained of the barbarity of the prevailing modes of punishment; those who believed it possible to alter rather than just punish criminal behaviour; and those who wanted a more rational system of punishment to better deter crime. The champion for all three of these groups was Englishman John Howard, who in 1777 published a two volume study entitled Prisons and Lazarettos. In this work a number of British and some European prisons were described. Howard criticized British prisons for being squalid schools for crime where young offenders languished in the company of hardened criminals. He claimed that in Europe there were institutions where criminals were led by the very nature of their prison experience to improve their behaviour and that this behavioral change was not brought about simply through punishment but also through penitence and moral reform. In one of the European prisons that Howard visited, inmates were kept in separate cells arranged around a central altar. By reflecting on their crimes and expressing their guilt and sorrow to God, criminals atoned for their sins. Howard proposed a penitentiary designed to encourage this experience. Believing that crime, like lunacy, was connected with general social ills such as poverty, ignorance, drunkenness and other vices, Howard argued that prisoners must be subjected to rigid discipline involving hard work and reflection if they were to be morally reformed. He was thus responsible for developing and popularizing the concept of the penitentiary, which during the nineteenth century became the principal mode of treating serious criminal offenders.

     It was not until the second quarter of the nineteenth century that these new institutions of confinement were imported into Canada. Before then the old fashioned jail system handled most deviants; moreover, the population was so small and scattered that large institutions of any kind were unnecessary and impractical. Following the Napoleonic Wars, however, a flood of immigrants to Canada created widespread concern about what was thought to be a general increase in criminality, mental disease and deviance.

     Recognizing that the existing jails and madhouses could not cope with the need to confine greater numbers of people, Canadians looked to Europe and the United States for alternative models. Americans were concerned about the effects of massive immigration, modernization and new democratic attitudes on the stability of society. There, too, reform groups were influenced by a belief that society could be perfected through social engineering. In the 1820s the Boston Prison Discipline Society became a leading exponent of new penitentiary theories and helped popularize these new theories in Canada.

     By the end of the eighteenth century, mental institutions had been created in England and France that utilized a technique known as moral treatment. Also called the "humane method" or the "soothing system," this approach quickly gained the endorsement of asylum promoters in North America. Not really a treatment in the medical sense, the moral method relied on compassion and gentle discipline. The modern asylum provided a strictly regulated environment in which the deranged mind could find order to calm itself. Patients were no longer roughly handled. Rather than being locked away to brood over their morbid delusions, they were now to engage in activities that would distract them from their former preoccupations. Ample exercise, plenty of hard work, cheerful amusements and a healthy diet were the elements of moral treatment that constituted this new daily regime.

     As the term moral treatment implies, such therapy was concerned with reasserting the prevailing moral standards. The stress on morality derived from the belief that sin or immorality was an important cause of madness. Accordingly, any kind of anti-social behaviour, including drunkenness, gambling, overeating, adultery and masturbation, was thought to jeopardize one's sanity. The asylum was therefore rigidly organized to reinforce self-control and to promote socially acceptable standards of conduct. Productive labour, religious observances, regular habits and cleanliness were of such paramount importance that they overshadowed any medical procedure. The asylum was a system. Everything from the location of its buildings to the inmates' table manners was designed to transform behaviour through the internalization of correct moral standards.

     The construction of penitentiaries based on these new theories generally lagged behind that of asylums. Medical men - Dr. George Peters in New Brunswick, Dr. Charles Duncombe in Upper Canada, Dr. Henry Hunt in Newfoundland, Dr. James Douglas in Lower Canada agitated for the construction of mental asylums in British North America. In the course of their work, they had been touched by the lunatic's plight. Confident that they knew how to remedy mental illness, these reformers led the campaign for public support. Insanity, stated Charles Duncombe, was as easily cured "as the ordinary diseases of the climate." Treatment in the early stages was seen as crucial. If the afflicted person was removed from his home to an asylum within the first three months, a cure was virtually assured. Whereas the family had once been the primary agent of care, medical opinion and eventually the conventional wisdom became that "no insane man recovers at home." Insanity required moral treatment and moral treatment required the asylum.

     Initially, however, the reformers' zeal outpaced the public's willingness or ability to provide separate hospitals for the insane. The early institutions were consequently makeshift and inadequate. The first mental hospital in British North America was located in the basement of a converted cholera hospital in Saint John, New Brunswick. It opened its doors in 1836. In Toronto the small, wood frame Home District Gaol was emptied of prisoners in 1841 to be turned into a temporary asylum for insane persons. On the outskirts of Quebec City an old stone manor-house at the seigneury of Beauport was fitted out as an asylum and received its first patients in the fall of 1845. In Newfoundland a farm was pressed into service; in British Columbia, a former smallpox hospital. In every case, the inmates probably enjoyed better care than they would have had before, but hand me down facilities could not bring about the revolution in mental health care that activists desired.

     By the middle of the century the process of replacing these earliest mental institutions with large permanent hospitals providing the modern "moral" treatment was under way. Once again New Brunswick was in the forefront: a new asylum, overlooking the Reversing Falls, was opened in Saint John in 1848. The Provincial Lunatic Asylum began operations in Toronto in 1850, to be followed by institutions in Newfoundland (1854) and Nova Scotia (1859). In Western Canada, where smaller populations made the need less acute, asylums were not built until the last quarter of the century.

     All of the institutions mentioned above were publicly owned except the ones in Quebec, where the government chose to adopt a "farming out" system. The asylum at Beauport, and subsequent mental hospitals in that province, were privately owned and operated. The Quebec government gave proprietors an annual per capita grant for the maintenance of patients unable to pay for their own care.

     Up until Confederation, the only serious effort to implement modern theories of criminal treatment and reform via the establishment of a new penal institution was in Upper Canada. Early in the 1830s, a committee of the Legislative Assembly visited several institutions in Britain and the United States and recommended the construction of a penitentiary along the lines suggested by Howard. "The aim of a penitentiary," the report stated, "was not only to protect society and punish offenders, but by inducing a penitent attitude in prisoners to effect a reformation of their characters." The government approved the report and in 1832 work began at a site near Kingston. Although the building proceeded in stages, the design not being fully realized until the 1850s, it became one of the most up-to-date institutions of its day.

     The Kingston Penitentiary featured several of the latest innovations in penal architecture, including a central rotunda and radiating wings containing cell blocks. It "created" inmates with a systematic form of prison discipline. This method, based on theories of John Howard, involved a strict routine of hard work in communal silence by day, and separate confinement in individual cells by night. "To rescue the child of ignorance and vice from almost certain destruction to which he hastens; to guard from contamination the venial offender...; to implant religious and moral principles and industrious habits on the inmates of the Penitentiary; and to strengthen and encourage him in his struggles with the world when he is discharged from confinement" the penitentiary suppressed prisoners' individual identity and subjected them to a routine of rigid conformity.

     The Kingston institution remained the only full-fledged Canadian penitentiary until after Confederation. With the union of Upper and Lower Canada in 1841, convicts from Quebec were sent there. Elsewhere, some county jails, such as those in Halifax and Toronto, incorporated features of the penitentiary system, and by Confederation most provincial jails had facilities for the separate confinement of prisoners.

     After 1867 the responsibility of rehabilitating criminals was divided between the provincial and federal governments. Offenders convicted of lesser crimes entailing fines or sentences of under two years came under the jurisdiction of the provincial government, while those subject to the death penalty or long prison sentences became the responsibility of the federal government. Although the provinces did establish penitentiaries for the incarceration of prisoners serving short sentences, the duration of their term was not considered sufficient for prison discipline to have any real effect. Provincial institutions therefore tended to be less rigorous in their enforcement of the system of silent labour, although the buildings were constructed according to the design of the day which included cell blocks and catwalks.

     During the 1870s a building program was initiated to establish federal penitentiaries in each region of the Dominion. A former boy's reformatory was enlarged into a penitentiary at St. Vincent de Paul, near Montreal, in 1873. Identical buildings were constructed in Manitoba and British Columbia in 1876 and 1878 and the following year a penitentiary was completed near Moncton at Dorchester, New Brunswick. During most of the nineteenth century, these institutions were all run according to the Kingston model and the philosophy upon which it was based: that prisons were "schools where the ignorant are enlightened and the repentant strengthened - in which expiation for crime is not lost sight of, but the permanent moral reform of the convict is the chief aim." 

The End of Optimism 

     The new institutions of confinement were established in a spirit of great optimism. The confidence that deviant behaviour could be corrected under the right circumstances was widespread. Mental illness, for instance, was everywhere believed to be in retreat before the combined forces of moral treatment and the asylum. 

     Unfortunately, it was not long before the new institutions disappointed their founders. In the case of mental hospitals, effective moral treatment required a strict system of classification, a manageable number of patients and a sympathetic staff. Instead, asylums overflowed with an inmate population that included epileptics, retardates and the senile. Once the practice of institutionalizing the mentally ill was aggressively adopted, hospitals could not handle the large number of patients being thrust upon them. Toronto's Provincial Lunatic Asylum, built to accommodate two hundred and fifty inmates, was crowded with close to four hundred in the 1860s. As lack of space made classification difficult, the mildly depressed often mingled with the wildly frantic. Staff was ill-trained and poorly paid. At one time it was even claimed that in Prince Edward Island "an ordinary labourer" was in charge of the asylum. Given these circumstances it may have been inevitable that physical restraints were again used to control inmates. A British asylum reformer, Daniel Hack Tuke, visited the Qubec asylums in 1884 and discovered many patients bound in restraining devices. The inmates he saw inhabited tiny, windowless cells. They communicated with their warders through a wicket in the door. Many were shackled in handcuffs and passed their days wandering the gloomy corridors. Others were strapped to their beds. These conditions were duplicated in other provinces. In Nova Scotia's Mount Hope Asylum, for example, there were documented cases of inmates freezing to death in their cells. Some inmates were placed in a kind of solitary confinement called a "dark room" where they were deliberately starved to weaken them and make them submissive. In British Columbia mental patients were routinely beaten and ducked in water.

     Penitentiaries continuously faced the problem of keeping on the right side of the fine line between discipline and brutality. Periodic investigations into the Kingston Penitentiary found evidence of cruel treatment of prisoners although faith in the perfectibility of the system was maintained. Critics often pointed to the low qualifications of the prison staff, yet much of the harsh treatment was inherent in the system itself. Inmates were confined for much of each day in stone cells only large enough for a bed, a stool and a bucket. Cells were cold, damp, smelly and dark. Talking between prisoners was forbidden and work was intended to be hard and boring. Visitors were not allowed. When regulations were broken, inmates were punished severely.

     As the statistics on repeat offenders showed, the penitentiary system failed to correct criminal behaviour. Instead of rehabilitating prisoners, it turned out hardened criminals. Administrators tinkered with the system in an attempt to achieve better results. They tried lenience; they tried harsh discipline; they tried longer sentences; they tried indeterminate sentences. Nothing had an appreciable effect; the number of inmates continued to grow.

     Attempts to arrest the deterioration of mental hospitals also failed. Asylums became a provincial responsibility following Confederation and various governments conducted formal investigations into charges of patient abuse. Since overcrowding was thought to be the main problem, several new hospitals were opened in the last quarter of the nineteenth century. By 1900 Quebec had four institutions and Ontario seven. Some of the new facilities were intended solely to care for chronic cases whose prognosis was poor or whose illness was due to congenital defect, disease or senility. In Nova Scotia, for example, there were fifteen county asylums housing inmates who were never expected to recover and go home.

     Other changes recommended by those investigating mental hospitals were improved training for asylum personnel, better classification of inmates and the banning of sightseers. While some of these changes may have improved life in the asylums, they did not succeed in either giving moral treatment a second chance or introducing new therapeutic methods.

     By the end of the century the optimism that earlier characterized the treatment of the mentally ill; had been replaced by resignation and a very limited sense of what could be done. It was taken for granted that a small percentage of patients would never be cured. "Out of four hundred and forty-two patients," admitted the superintendent of the New Brunswick asylum in 1881, "only sixteen were expected to be restored to mental health." Like the penitentiary, the mental institution had come full circle. Once again it was perceived as a place of confinement in which the mentally ill languished without therapy and with almost no expectation that they would ever recover.

Conclusion 

     Until quite recently, historians typically characterized the creation of asylums and penitentiaries during the nineteenth century as examples of the moral progress of mankind. Invoking images of the lunatic in chains or the criminal bound in stocks, these traditional reform historians believed that asylums and penitentiaries represented an improvement over the "barbaric" practices that had preceded them. Not only were the institutions more humane, they argued, they were also more enlightened because they substituted therapy and rehabilitation for simple confinement.

     In the last two decades, historians have increasingly questioned the proposition that incarcerating large numbers of people in asylums and penitentiaries during the last half of the nineteenth century constituted an improvement on former practices. Some say that the institutions of confinement represented not reform but a new form of repression; that they merely replaced psychological coercion for physical coercion; and that corporal punishment lost favour not because it was inhuman but because it was inefficient. Others regard the new asylums and penitentiaries as agents of social control, isolating deviants and maintaining order at a time when rapid industrialization was disrupting society. Some claim the institutions were part of a defensive strategy by which the middle class, made nervous by social change, imposed their own values on the rest of society.

     What all these explanations have in common is a disdain for the reform model and its claims to moral superiority. Revisionist historians look beyond the rhetoric of asylum and penitentiary promoters to the social conditions in which crime, insanity and institutional confinement flourished. They believe that the new institutions were created not because they were morally advanced but because they served specific purposes in a society challenged by industrialization and urban growth.

     Today, about one hundred and fifty years after they were created, penitentiaries and mental hospitals are still familiar forms on the social landscape. Increasingly however, it is being argued that incarceration is not the only, or the best, way of dealing with deviant behaviour. Modern reformers insist that institutions have become too large and impersonal and that they tend to exacerbate the behaviour they were created to correct. These reformers now argue for de-institutionalizing some criminals and mental patients. Obligatory community service rather than imprisonment, for example, is beginning to be seen as appropriate punishment for certain types of crime. Criminals are already being sent to half-way houses, and there is renewed interest in treating mental patients in the home. While these approaches are being debated, mental asylums and penitentiaries remain with us.  

